from datetime import datetime
from typing import List, Optional, Dict, Any

from janis_core import *
from janis_core.types.common_data_types import Boolean, File, String, Int

Predict_Traits_Py_V0_1_0 = CommandToolBuilder(tool="predict_traits.py", base_command=["predict_traits.py"], inputs=[ToolInput(tag="in_verbose", input_type=Boolean(optional=True), prefix="--verbose", doc=InputDocumentation(doc="Print information during execution -- useful for\ndebugging [default: False]")), ToolInput(tag="in_output_trait_table", input_type=File(optional=True), prefix="--output_trait_table", doc=InputDocumentation(doc="the output filepath for trait predictions [default:\npredicted_states.tsv]")), ToolInput(tag="in_calculate_accuracy_metrics", input_type=File(optional=True), prefix="--calculate_accuracy_metrics", doc=InputDocumentation(doc="if specified, calculate accuracy metrics (i.e. how\naccurate does PICRUSt expect its predictions to be?)\nand add to output file [default: False]")), ToolInput(tag="in_output_accuracy_metrics_only", input_type=File(optional=True), prefix="--output_accuracy_metrics_only", doc=InputDocumentation(doc="if specified, calculate accuracy metrics (e.g. NSTI),\noutput them to this filepath, and do not do anything\nelse. [default: none]")), ToolInput(tag="in_prediction_method", input_type=String(optional=True), prefix="--prediction_method", doc=InputDocumentation(doc="Specify prediction method to use.  The recommended\nprediction method is set as default, so other options\nare primarily useful for control experiments and\nmethods validation, not typical use.  Valid choices ar\ne:asr_and_weighting,nearest_neighbor,asr_only,weightin\ng_only,random_neighbor.\n'asr_and_weighting'(recommended): use ancestral state\nreconstructions plus local weighting with known tip\nnodes.  'nearest_neighbor': predict the closest tip on\nthe tree with trait information.\n'random_annotated_neighbor': predict a random tip on\nthe tree with trait information. 'asr_only': predict\nthe traits of the last reconstructed ancestor, without\nweighting. 'weighting_only': weight all genomes by\ndistance, to the organism of interest using the\nspecified weighting function and predict the weighted\naverage.   [default: asr_and_weighting]")), ToolInput(tag="in_weighting_method", input_type=Int(optional=True), prefix="--weighting_method", doc=InputDocumentation(doc="Specify prediction the weighting function to use.\nThis only applies to prediction methods that\nincorporate local weighting ('asr_and_weighting' or\n'weighting_only')  The recommended weighting  method\nis set as default, so other options are primarily\nuseful for control experiments and methods validation,\nnot typical use.  Valid choices\nare:exponential,linear,equal.\n'exponential'(recommended): weight genomes as a\nnegative exponent of distance.  That is 2^-d, where d\nis the tip-to-tip distance from the genome to the tip.\n'linear': weight tips as a linear function of weight,\nnormalized to the maximum possible distance (max_d\n-d)/d. 'equal_weights': set all weights to a constant\n(ignoring branch length).   [default: exponential]")), ToolInput(tag="in_limit_predictions_by_otu_table", input_type=File(optional=True), prefix="--limit_predictions_by_otu_table", doc=InputDocumentation(doc="Specify a valid path to a legacy QIIME OTU table to\nperform predictions only for tips that are listed in\nthe OTU table (regardless of abundance)")), ToolInput(tag="in_limit_predictions_to_organisms", input_type=Int(optional=True), prefix="--limit_predictions_to_organisms", doc=InputDocumentation(doc="Limit predictions to specific, comma-separated\norganims ids. (Generally only useful for lists of < 10\norganism ids, for example when performing leave-one-\nout cross-validation).")), ToolInput(tag="in_reconstructed_trait_table", input_type=String(optional=True), prefix="--reconstructed_trait_table", doc=InputDocumentation(doc="the input trait table describing reconstructed traits\n(from ancestral_state_reconstruction.py) in tab-\ndelimited format [default: none]")), ToolInput(tag="in_confidence_format", input_type=File(optional=True), prefix="--confidence_format", doc=InputDocumentation(doc="the format for the confidence intervals from ancestral\nstate reconstruction. Only needed if passing a\nreconstruction confidence file with -c or\n--reconstruction_confidence.  These are typically\nsigma values for maximum likelihood ASR  methods, but\n95% confidence intervals for phylogenetic independent\ncontrasts (e.g. from the ape R packages ace function\nwith pic as the reconstruction method).  Valid choices\nare:sigma,confidence_interval. [default: sigma]")), ToolInput(tag="in_reconstruction_confidence", input_type=String(optional=True), prefix="--reconstruction_confidence", doc=InputDocumentation(doc="the input trait table describing confidence intervals\nfor reconstructed traits (from\nancestral_state_reconstruction.py) in tab-delimited\nformat [default: none]")), ToolInput(tag="in_output_pre_calc_file_in_biom", input_type=File(optional=True), prefix="--output_precalc_file_in_biom", doc=InputDocumentation(doc="Instead of outputting the precalculated file in tab-\ndelimited format (with otu ids as row ids and traits\nas columns) output the data in biom format (with otu\nas SampleIds and traits as ObservationIds) [default:\nFalse]")), ToolInput(tag="in_no_round", input_type=Boolean(optional=True), prefix="--no_round", doc=InputDocumentation(doc="Flag to set if you do not want predictions to be\nrounded to the nearest integer [default: False]")), ToolInput(tag="in_observed_trait_table", input_type=String(optional=True), prefix="--observed_trait_table", doc=InputDocumentation(doc="the input trait table describing directly observed\ntraits (e.g. sequenced genomes) in tab-delimited\nformat [REQUIRED]")), ToolInput(tag="in_tree", input_type=String(optional=True), prefix="--tree", doc=InputDocumentation(doc="the full reference tree, in Newick format [REQUIRED]\n")), ToolInput(tag="in_one_dot", input_type=Int(), position=0, doc=InputDocumentation(doc="For each terminal (tip) node where a prediction is to be performed, the algorithm through the reconstructed ancestral states, and finds the last node in the ancestry of our organism of interest for which a prediction is available")), ToolInput(tag="in_two_dot", input_type=Int(), position=1, doc=InputDocumentation(doc="The trait for the organism is then predicted based on a branch-length weighted average of the ancestral node and it's close relatives. (This is necessary because technical limitations involving the handling of ambiguous characters in many Ancestral State Reconstruction programs prevent the parent node of the organism from being directly reconstructed in most cases.)"))], outputs=[ToolOutput(tag="out_output_trait_table", output_type=File(optional=True), selector=InputSelector(input_to_select="in_output_trait_table", type_hint=File()), doc=OutputDocumentation(doc="the output filepath for trait predictions [default:\npredicted_states.tsv]")), ToolOutput(tag="out_calculate_accuracy_metrics", output_type=File(optional=True), selector=InputSelector(input_to_select="in_calculate_accuracy_metrics", type_hint=File()), doc=OutputDocumentation(doc="if specified, calculate accuracy metrics (i.e. how\naccurate does PICRUSt expect its predictions to be?)\nand add to output file [default: False]")), ToolOutput(tag="out_output_accuracy_metrics_only", output_type=File(optional=True), selector=InputSelector(input_to_select="in_output_accuracy_metrics_only", type_hint=File()), doc=OutputDocumentation(doc="if specified, calculate accuracy metrics (e.g. NSTI),\noutput them to this filepath, and do not do anything\nelse. [default: none]")), ToolOutput(tag="out_output_pre_calc_file_in_biom", output_type=File(optional=True), selector=InputSelector(input_to_select="in_output_pre_calc_file_in_biom", type_hint=File()), doc=OutputDocumentation(doc="Instead of outputting the precalculated file in tab-\ndelimited format (with otu ids as row ids and traits\nas columns) output the data in biom format (with otu\nas SampleIds and traits as ObservationIds) [default:\nFalse]"))], container=None, version="v0.1.0")


if __name__ == "__main__":
    # or "cwl"
    Predict_Traits_Py_V0_1_0().translate("wdl", allow_empty_container=True)

